@@ -25,9 +25,11 @@
 #include <glib/gi18n.h>
 #include <glib.h>
 #include <gio/gio.h>
+#include <gdesktop-enums.h>
 
 #include "sj-metadata-gvfs.h"
 #include "sj-structures.h"
+#include "sj-util.h"
 #include "sj-error.h"
 
 struct SjMetadataGvfsPrivate {
@@ -45,7 +47,8 @@ enum {
   PROP_PROXY_HOST,
   PROP_PROXY_PORT,
   PROP_PROXY_USERNAME,
-  PROP_PROXY_PASSWORD
+  PROP_PROXY_PASSWORD,
+  PROP_PROXY_MODE
 };
 
 static void metadata_iface_init (gpointer g_iface, gpointer iface_data);
@@ -82,6 +85,7 @@ gvfs_list_albums (SjMetadata *metadata, char **url, GError **error)
   GFileInfo *info;
   GFileEnumerator *e;
   guint i = 1;
+  const char *str;
 
   g_return_val_if_fail (SJ_IS_METADATA_GVFS (metadata), NULL);
 
@@ -102,15 +106,18 @@ gvfs_list_albums (SjMetadata *metadata, char **url, GError **error)
   album = g_new0(AlbumDetails, 1);
 
   /* Get the album metadata */
-  if (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.title") != NULL) {
+  str = g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.title");
+  if (!sj_str_is_empty (str)) {
     album->metadata_source = SOURCE_CDTEXT;
-    album->title = g_strdup (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.title"));
+    album->title = g_strdup (str);
   } else {
     album->metadata_source = SOURCE_FALLBACK;
     album->title = g_strdup (_("Unknown Title"));
   }
-  album->artist = g_strdup (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.artist"));
-  if (album->artist == NULL)
+  str = g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.artist");
+  if (!sj_str_is_empty (str))
+    album->artist = g_strdup (str);
+  else
     album->artist = g_strdup (_("Unknown Artist"));
   album->genre = g_strdup (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.genre"));
 
@@ -131,11 +138,15 @@ gvfs_list_albums (SjMetadata *metadata, char **url, GError **error)
     track = g_new0 (TrackDetails, 1);
     track->number = i;
     track->album = album;
-    track->title = g_strdup (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.title"));
-    if (track->title == NULL)
+    str = g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.title");
+    if (!sj_str_is_empty (str))
+      track->title = g_strdup (str);
+    else
       track->title = g_strdup_printf (_("Track %d"), i);
-    track->artist = g_strdup (g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.artist"));
-    if (track->artist == NULL || track->artist[0] == '\0') {
+    str = g_file_info_get_attribute_string (info, "xattr::org.gnome.audio.artist");
+    if (!sj_str_is_empty (str)) {
+      track->artist = g_strdup (str);
+    } else {
       if (album->artist == NULL)
         track->artist = g_strdup (_("Unknown Artist"));
       else
@@ -193,6 +204,10 @@ sj_metadata_gvfs_get_property (GObject *object, guint property_id,
     /* Do nothing */
     g_value_set_int (value, 0);
     break;
+  case PROP_PROXY_MODE:
+    /* Do nothing */
+    g_value_set_enum (value, G_DESKTOP_PROXY_MODE_NONE);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -217,6 +232,7 @@ sj_metadata_gvfs_set_property (GObject *object, guint property_id,
   case PROP_PROXY_PORT:
   case PROP_PROXY_USERNAME:
   case PROP_PROXY_PASSWORD:
+  case PROP_PROXY_MODE:
     /* Do nothing */
     break;
   default:
@@ -269,6 +285,8 @@ sj_metadata_gvfs_class_init (SjMetadataGvfsClass *class)
                                     PROP_PROXY_USERNAME, "proxy-username");
   g_object_class_override_property (object_class,
                                     PROP_PROXY_PASSWORD, "proxy-password");
+  g_object_class_override_property (object_class,
+                                    PROP_PROXY_MODE, "proxy-mode");
 }
 
 
